cmocka
======

cmocka is an elegant unit testing framework for C with support for mock
objects. It only requires the standard C library, works on a range of computing
platforms (including embedded) and with different compilers.

For information about how to use the cmocka unit testing framework see
doc/index.html or https://api.cmocka.org/.

Compiling
---------

To compile the cmocka library and example applications run, create a build dir,
and in the build dir call 'cmake /path/to/cmocka' followed by 'make'. On
Windows you can use the cmake gui. More details can be found in the INSTALL file.

Website
-------

https://cmocka.org
